import platform
import os
import subprocess
import sys

def copy(text):
    if platform.system() == "Linux" :

        if os.getenv('WAYLAND_DISPLAY'):
            os.system(f'echo "{text}" | wl-copy')

        else:
            os.system(f'echo "{text}" | xclip -selection clipboard')

    elif platform.system() == "Darwin":
        os.system(f'echo "{text}" | pbcopy')

    elif platform.system() == "Windows":
        os.system(f'echo "{text}" | clip')

def run_command(command):
   
    result = subprocess.run(command, shell=True, capture_output=True, text=True)
    if result.returncode == 0:
        return result.stdout.strip()
    else:
        raise RuntimeError(f"Command '{command}' failed with exit code {result.returncode}")

def paste():
    if platform.system() == "Linux" :

        if os.getenv('WAYLAND_DISPLAY'):
            text = run_command('wl-paste')

        else:
            text = run_command('xclip -o -selection clipboard')

    elif platform.system() == "Darwin":
        text = run_command('pbpaste')

    elif platform.system() == "Windows":
        text = run_command('echo | clip')
    
    return text

if __name__ == "__main__":
    if len(sys.argv) > 1:
        text = sys.argv[1]
        copy(text)
    else:
        paste()


from setuptools import setup, find_packages
from pyclipmgr import copy, paste

setup(
    name='pyclipmgr',
    packages=find_packages(),
    scripts=['pyclipmgr.py'],  # List of script files to be installed
    version='2.4',
    entry_points={
        'console_scripts': [
            'pyclipmgr-copy = pyclipmgr:copy',
            'pyclipmgr-paste = pyclipmgr:paste',
        ]
    },
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='sudo man',
    author_email='supertechman@yahoo.com',
    description="this lib check for your machine's platform and use system commands to contact with clipboard (copy or paste) in python",
    url='https://github.com/mohammed-saleh2007/py-clip-mgr',
)
